@@ -1,8 +1,10 @@
+import io
 import json
+import pandas as pd
 from pathlib import Path
 
-from starlette.responses import Response
 from pymultirole_plugins.v1.schema import Document
+from starlette.responses import Response
 
 from pyformatters_tabular.tabular import TabularFormatter, TabularParameters, OutputFormat
 
@@ -37,3 +39,23 @@ def test_csv():
         result = Path(testdir, 'data/response_1621334812115.csv')
         with result.open("wb") as fout:
             fout.write(resp.body)
+
+
+def test_slots():
+    testdir = Path(__file__).parent
+    source = Path(testdir, 'data/slots.json')
+    output_file = Path(testdir, 'data/slots.xlsx')
+    formatter = TabularFormatter()
+    options = TabularParameters(format=OutputFormat.csv, as_slots=True)
+    with source.open("r") as fin:
+        docs = json.load(fin)
+        dfs = []
+        for doc in docs:
+            doc = Document(**doc)
+            resp: Response = formatter.format(doc, options)
+            assert resp.status_code == 200
+            content = io.TextIOWrapper(io.BytesIO(resp.body), encoding=resp.charset)
+            df = pd.read_csv(content)
+            dfs.append(df)
+        concatenated = pd.concat(dfs, ignore_index=True)
+        concatenated.to_excel(str(output_file), index=False)
